%global apiversion 0.3
%define fname mwaw
%define major 3
%define libname %mklibname %fname %major
%define develname %mklibname -d %fname

Name: libmwaw
Version: 0.3.4
%define subrel 1
Release: %mkrel 3
Summary: Import library for some old mac text documents

Group: System/Libraries
License: LGPLv2+ or MPLv2.0
URL: http://sourceforge.net/projects/libmwaw/
Source: http://downloads.sourceforge.net/%{name}/%{name}-%{version}.tar.xz

Patch0: libmwaw-0.3.1-CVE-2017-9433.patch

BuildRequires: automake
BuildRequires: boost-devel
BuildRequires: doxygen
BuildRequires: help2man
BuildRequires: pkgconfig(librevenge-0.0)

%description
libmwaw contains import filters for many old mac documents, mostly text
formats like ClarisWorks, MacWrite or MS Word for Mac, but it has a
limited support for vector drawings and spreadsheets as well (limited in
the sense that it treats them as text documents). Full list of supported
formats is available at https://sourceforge.net/p/libmwaw/wiki/Home/ .

%package -n %libname
Summary: System/Libraries
Group: System/Libraries

%description -n %libname
The %libname package contains libraries and header files for
developing applications that use %{name}.

%package -n %develname
Summary: Development files for %{name}
Group: Development/C
Requires: %libname = %version
Provides: %{fname}-devel lib%{fname}-devel

%description -n %develname
The %develname package contains libraries and header files for
developing applications that use %{name}.

%package doc
Summary: Documentation of %{name} API
Group: Documentation
BuildArch: noarch

%description doc
The %{name}-doc package contains documentation files for %{name}.

%package tools
Summary: Tools to transform the supported formats into other formats
Group: Documentation
License: LGPLv2+

%description tools
Tools to transform the supported document formats into other formats.
Supported output formats are CSV, XHTML, text and raw.

%prep
%autosetup -p1


%build
aclocal
automake --add-missing
%configure2_5x --disable-static --disable-werror --disable-zip --enable-docs
sed -i \
    -e 's|^hardcode_libdir_flag_spec=.*|hardcode_libdir_flag_spec=""|g' \
    -e 's|^runpath_var=LD_RUN_PATH|runpath_var=DIE_RPATH_DIE|g' \
    libtool
%make V=1

export LD_LIBRARY_PATH=`pwd`/src/lib/.libs${LD_LIBRARY_PATH:+:${LD_LIBRARY_PATH}}
help2man -N -n 'convert Mac spreadsheet into CSV' -o mwaw2csv.1 ./src/conv/csv/.libs/mwaw2csv
help2man -N -n 'debug the conversion library' -o mwaw2raw.1 ./src/conv/raw/.libs/mwaw2raw
help2man -N -n 'convert Mac text document into HTML' -o mwaw2html.1 ./src/conv/html/.libs/mwaw2html
help2man -N -n 'convert Mac drawing into SVG' -o mwaw2svg.1 ./src/conv/svg/.libs/mwaw2svg
help2man -N -n 'convert Mac text document into plain text' -o mwaw2text.1 ./src/conv/text/.libs/mwaw2text

%install
%makeinstall_std
rm -f %{buildroot}/%{_libdir}/*.la
# it seems this tool is only useful on MacOS
rm -f %{buildroot}/%{_bindir}/mwawFile
# rhbz#1001297 we install API docs directly from build
rm -rf %{buildroot}/%{_docdir}/%{name}

install -m 0755 -d %{buildroot}/%{_mandir}/man1
install -m 0644 mwaw2*.1 %{buildroot}/%{_mandir}/man1

%files -n %libname
%doc CHANGES COPYING.* README
%{_libdir}/%{name}-%{apiversion}.so.%{major}*

%files -n %develname
%{_includedir}/%{name}-%{apiversion}
%{_libdir}/%{name}-%{apiversion}.so
%{_libdir}/pkgconfig/%{name}-%{apiversion}.pc

%files doc
%doc COPYING.*
%doc docs/doxygen/html

%files tools
%{_bindir}/*
%{_mandir}/man1/*


%changelog
* Sun Jun 11 2017 luigiwalser <luigiwalser> 0.3.4-3.1.mga5
+ Revision: 1107571
- add patch from debian to fix CVE-2017-9433

* Sun Feb 01 2015 tv <tv> 0.3.4-3.mga5
+ Revision: 812974
- submit to core/release

* Sat Jan 31 2015 tv <tv> 0.3.4-2.mga5
+ Revision: 812834
+ rebuild (emptylog)

* Sat Jan 24 2015 tv <tv> 0.3.4-1.mga5
+ Revision: 812105
- new release

* Wed Oct 15 2014 umeabot <umeabot> 0.3.2-4.mga5
+ Revision: 748725
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 0.3.2-3.mga5
+ Revision: 726802
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 0.3.2-2.mga5
+ Revision: 681627
- Mageia 5 Mass Rebuild

* Sat Aug 16 2014 tv <tv> 0.3.2-1.mga5
+ Revision: 664177
- drop merged patches
- new release

* Thu Jul 31 2014 tv <tv> 0.3.1-1.mga5
+ Revision: 658681
- adjust file list
- fix install
- bump major
- fix BR
- fix build
- build w/o librevenge-stream for now
- BR librevenge
- new release

* Wed Feb 05 2014 tv <tv> 0.2.0-1.mga5
+ Revision: 583633
- bump major
- new release

* Sat Oct 19 2013 umeabot <umeabot> 0.1.11-2.mga4
+ Revision: 534941
- Mageia 4 Mass Rebuild

* Mon Sep 16 2013 tv <tv> 0.1.11-1.mga4
+ Revision: 480215
- new release

* Sat Aug 03 2013 fwang <fwang> 0.1.10-1.mga4
+ Revision: 462852
- use configure2_5x
- new version 0.1.10

* Sat May 25 2013 tv <tv> 0.1.9-5.mga4
+ Revision: 426977
- fix provides

* Sat May 25 2013 tv <tv> 0.1.9-4.mga4
+ Revision: 426968
- add more devel provides
- add devel provides

* Sat May 25 2013 tv <tv> 0.1.9-2.mga4
+ Revision: 426954
- fix requires

* Sat May 25 2013 tv <tv> 0.1.9-1.mga4
+ Revision: 426949
- imported package libmwaw

